@@ -72,8 +72,7 @@ __all__ = [
     "mdctspecapp",
     "me",
     "mich",
-    "michctapp_p",
-    "michctapp_u",
+    "michctapp",
     "minn",
     "minnag",
     "minnctapp",
