@@ -7,14 +7,14 @@ Date created: 06/27/2014
 """
 
 
-from juriscraper.opinions.united_states.state import md
-
 from datetime import date
 
+from juriscraper.opinions.united_states.state import md
+
 
 class Site(md.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = "https://www.mdcourts.gov/cgi-bin/indexlist.pl?court=cosa&year={current_year}&order=bydate&submit=Submit".format(
             current_year=date.today().year
         )
