@@ -51,6 +51,6 @@ class Site(OpinionSite):
     def _get_precedential_statuses(self):
         return ["Published"] * len(self.case_names)
 
-    def _get_neutral_citations(self):
+    def _get_citations(self):
         path = f"{self.path_root}//td[1]//text()"
         return list(self.html.xpath(path))
