@@ -7,20 +7,20 @@ Reviewer:
 
 import re
 
-from juriscraper.OpinionSite import OpinionSite
 from juriscraper.lib.string_utils import convert_date_string
+from juriscraper.OpinionSite import OpinionSite
 
 
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.domain = "http://www.ag.state.mn.us"
         self.url = "http://www.ag.state.mn.us/office/opinions/DATE.asp"
         self.opinions = []
 
     def _download(self, request_dict={}):
-        html = super(Site, self)._download(request_dict)
+        html = super()._download(request_dict)
         self._extract_case_data_from_html(html)
         return html
 
