@@ -1,11 +1,12 @@
-from juriscraper.OpinionSite import OpinionSite
-from datetime import datetime
 import re
+from datetime import datetime
+
+from juriscraper.OpinionSite import OpinionSite
 
 
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.url = "http://www.courts.state.va.us/scndex.htm"
 
