@@ -5,6 +5,7 @@ from .case_query_advanced import CaseQueryAdvancedBankruptcy
 from .claims_register import ClaimsRegister
 from .docket_history_report import DocketHistoryReport
 from .docket_report import DocketReport
+from .email import NotificationEmail, S3NotificationEmail
 from .free_documents import FreeOpinionReport
 from .hidden_api import PossibleCaseNumberApi, ShowCaseDocApi
 from .http import PacerSession
@@ -22,6 +23,8 @@ __all__ = [
     DocketReport,
     FreeOpinionReport,
     InternetArchive,
+    NotificationEmail,
+    S3NotificationEmail,
     PacerRssFeed,
     PacerSession,
     PossibleCaseNumberApi,
